@@ -13,7 +13,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/butc/tcprocs.c,v 1.11 2003/12/07 22:49:23 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/butc/tcprocs.c,v 1.12 2004/07/13 05:52:46 shadow Exp $");
 
 #include <sys/types.h>
 #include <errno.h>
@@ -51,6 +51,20 @@ callPermitted(call)
     return 1;
 }
 
+/* XBSA Global Parameters */
+afs_int32 xbsaType;
+#ifdef xbsa
+struct butx_transactionInfo butxInfo;
+
+#define rpc_c_protect_level_default 0
+afs_uint32 dumpRestAuthnLevel = rpc_c_protect_level_default;
+char *xbsaObjectOwner;
+char *appObjectOwner;
+char *adsmServerName;
+char *xbsaSecToken;
+char *xbsalGName;
+#endif
+
 /* -------------------------
  * butc - interface routines - alphabetic order
  * -------------------------
